==> markets_insights-0.2.2-py3-none-any.whl: markets_insights/core/settings.py <==
from datetime import date


class BaseUrls:
    ParticipiantWiseOIData = ""


class MarketDaysSettings:
    HolidayOpenings = ([date(2020, 2, 24)],)  # open for Diwali Muhurat
    MarketHolidays = [
        date(2013, 10, 16),
        date(2013, 10, 2),
        date(2013, 10, 9),
        date(2013, 11, 15),
        date(2013, 11, 4),
        date(2013, 12, 25),
        date(2013, 3, 27),
        date(2013, 3, 29),
        date(2013, 4, 19),
        date(2013, 4, 24),
        date(2013, 5, 1),
        date(2013, 8, 15),
        date(2013, 8, 9),
        date(2013, 9, 9),
        date(2014, 10, 15),
        date(2014, 10, 2),
        date(2014, 10, 24),
        date(2014, 10, 3),
        date(2014, 10, 6),
        date(2014, 11, 4),
        date(2014, 11, 4),
        date(2014, 11, 6),
        date(2014, 11, 6),
        date(2014, 12, 15),
        date(2014, 12, 25),
        date(2014, 2, 27),
        date(2014, 3, 17),
        date(2014, 3, 19),
        date(2014, 4, 14),
        date(2014, 4, 18),
        date(2014, 4, 24),
        date(2014, 4, 8),
        date(2014, 5, 1),
        date(2014, 7, 29),
        date(2014, 8, 15),
        date(2014, 8, 29),
        date(2015, 1, 26),
        date(2015, 10, 16),
        date(2015, 10, 2),
        date(2015, 10, 22),
        date(2015, 11, 12),
        date(2015, 11, 25),
        date(2015, 12, 1),
        date(2015, 12, 25),
        date(2015, 2, 17),
        date(2015, 2, 2),
        date(2015, 3, 12),
        date(2015, 3, 13),
        date(2015, 3, 6),
        date(2015, 4, 14),
        date(2015, 4, 2),
        date(2015, 4, 3),
        date(2015, 5, 1),
        date(2015, 5, 19),
        date(2015, 7, 8),
        date(2015, 9, 17),
        date(2015, 9, 25),
        date(2015, 9, 4),
        date(2016, 1, 26),
        date(2016, 10, 11),
        date(2016, 10, 12),
        date(2016, 10, 31),
        date(2016, 11, 14),
        date(2016, 3, 24),
        date(2016, 3, 25),
        date(2016, 3, 7),
        date(2016, 4, 14),
        date(2016, 4, 15),
        date(2016, 4, 19),
        date(2016, 6, 20),
        date(2016, 7, 6),
        date(2016, 8, 15),
        date(2016, 9, 13),
        date(2016, 9, 5),
        date(2017, 1, 26),
        date(2017, 10, 2),
        date(2017, 10, 20),
        date(2017, 12, 25),
        date(2017, 2, 24),
        date(2017, 3, 13),
        date(2017, 4, 14),
        date(2017, 4, 4),
        date(2017, 5, 1),
        date(2017, 6, 26),
        date(2017, 8, 15),
        date(2017, 8, 25),
        date(2018, 1, 26),
        date(2018, 1, 26),
        date(2018, 10, 18),
        date(2018, 10, 2),
        date(2018, 11, 23),
        date(2018, 11, 8),
        date(2018, 12, 25),
        date(2018, 2, 13),
        date(2018, 2, 13),
        date(2018, 3, 2),
        date(2018, 3, 2),
        date(2018, 3, 29),
        date(2018, 3, 29),
        date(2018, 3, 30),
        date(2018, 3, 30),
        date(2018, 4, 10),
        date(2018, 4, 6),
        date(2018, 4, 9),
        date(2018, 5, 1),
        date(2018, 8, 15),
        date(2018, 8, 22),
        date(2018, 9, 13),
        date(2018, 9, 20),
        date(2019, 10, 2),
        date(2019, 10, 21),
        date(2019, 10, 28),
        date(2019, 10, 8),
        date(2019, 11, 12),
        date(2019, 12, 25),
        date(2019, 3, 21),
        date(2019, 3, 4),
        date(2019, 4, 17),
        date(2019, 4, 19),
        date(2019, 4, 29),
        date(2019, 5, 1),
        date(2019, 6, 5),
        date(2019, 8, 12),
        date(2019, 8, 15),
        date(2019, 9, 10),
        date(2019, 9, 2),
        date(2020, 10, 2),
        date(2020, 11, 16),
        date(2020, 11, 30),
        date(2020, 12, 25),
        date(2020, 2, 21),
        date(2020, 3, 10),
        date(2020, 4, 10),
        date(2020, 4, 14),
        date(2020, 4, 2),
        date(2020, 4, 6),
        date(2020, 5, 1),
        date(2020, 5, 25),
        date(2021, 1, 26),
        date(2021, 10, 15),
        date(2021, 10, 15),
        date(2021, 11, 19),
        date(2021, 11, 19),
        date(2021, 11, 5),
        date(2021, 11, 5),
        date(2021, 3, 11),
        date(2021, 3, 29),
        date(2021, 4, 14),
        date(2021, 4, 2),
        date(2021, 4, 21),
        date(2021, 5, 13),
        date(2021, 7, 21),
        date(2021, 7, 21),
        date(2021, 8, 10),
        date(2021, 8, 19),
        date(2021, 8, 19),
        date(2021, 9, 10),
        date(2021, 9, 10),
        date(2022, 1, 26),
        date(2022, 10, 25),
        date(2022, 10, 26),
        date(2022, 10, 5),
        date(2022, 11, 8),
        date(2022, 3, 1),
        date(2022, 3, 18),
        date(2022, 4, 14),
        date(2022, 4, 15),
        date(2022, 4, 28),
        date(2022, 5, 2),
        date(2022, 5, 27),
        date(2022, 5, 27),
        date(2022, 5, 3),
        date(2022, 6, 1),
        date(2022, 8, 15),
        date(2022, 8, 31),
        date(2022, 8, 9),
        date(2023, 1, 26),
        date(2023, 10, 2),
        date(2023, 10, 24),
        date(2023, 11, 14),
        date(2023, 11, 27),
        date(2023, 12, 25),
        date(2023, 3, 30),
        date(2023, 3, 7),
        date(2023, 4, 14),
        date(2023, 4, 4),
        date(2023, 4, 7),
        date(2023, 5, 1),
        date(2023, 6, 29),
        date(2023, 8, 15),
        date(2023, 9, 19),
    ]

==> markets_insights-0.4.2-py3-none-any.whl: markets_insights/core/settings.py <==
from datetime import date


class BaseUrls:
    ParticipiantWiseOIData = ""


class MarketDaysSettings:
    HolidayOpenings = ([date(2020, 2, 24)],)  # open for Diwali Muhurat
    MarketHolidays = [
        date(2013, 10, 16),
        date(2013, 10, 2),
        date(2013, 10, 9),
        date(2013, 11, 15),
        date(2013, 11, 4),
        date(2013, 12, 25),
        date(2013, 3, 27),
        date(2013, 3, 29),
        date(2013, 4, 19),
        date(2013, 4, 24),
        date(2013, 5, 1),
        date(2013, 8, 15),
        date(2013, 8, 9),
        date(2013, 9, 9),
        date(2014, 10, 15),
        date(2014, 10, 2),
        date(2014, 10, 24),
        date(2014, 10, 3),
        date(2014, 10, 6),
        date(2014, 11, 4),
        date(2014, 11, 4),
        date(2014, 11, 6),
        date(2014, 11, 6),
        date(2014, 12, 15),
        date(2014, 12, 25),
        date(2014, 2, 27),
        date(2014, 3, 17),
        date(2014, 3, 19),
        date(2014, 4, 14),
        date(2014, 4, 18),
        date(2014, 4, 24),
        date(2014, 4, 8),
        date(2014, 5, 1),
        date(2014, 7, 29),
        date(2014, 8, 15),
        date(2014, 8, 29),
        date(2015, 1, 26),
        date(2015, 10, 16),
        date(2015, 10, 2),
        date(2015, 10, 22),
        date(2015, 11, 12),
        date(2015, 11, 25),
        date(2015, 12, 1),
        date(2015, 12, 25),
        date(2015, 2, 17),
        date(2015, 2, 2),
        date(2015, 3, 12),
        date(2015, 3, 13),
        date(2015, 3, 6),
        date(2015, 4, 14),
        date(2015, 4, 2),
        date(2015, 4, 3),
        date(2015, 5, 1),
        date(2015, 5, 19),
        date(2015, 7, 8),
        date(2015, 9, 17),
        date(2015, 9, 25),
        date(2015, 9, 4),
        date(2016, 1, 26),
        date(2016, 10, 11),
        date(2016, 10, 12),
        date(2016, 10, 31),
        date(2016, 11, 14),
        date(2016, 3, 24),
        date(2016, 3, 25),
        date(2016, 3, 7),
        date(2016, 4, 14),
        date(2016, 4, 15),
        date(2016, 4, 19),
        date(2016, 6, 20),
        date(2016, 7, 6),
        date(2016, 8, 15),
        date(2016, 9, 13),
        date(2016, 9, 5),
        date(2017, 1, 26),
        date(2017, 10, 2),
        date(2017, 10, 20),
        date(2017, 12, 25),
        date(2017, 2, 24),
        date(2017, 3, 13),
        date(2017, 4, 14),
        date(2017, 4, 4),
        date(2017, 5, 1),
        date(2017, 6, 26),
        date(2017, 8, 15),
        date(2017, 8, 25),
        date(2018, 1, 26),
        date(2018, 1, 26),
        date(2018, 10, 18),
        date(2018, 10, 2),
        date(2018, 11, 23),
        date(2018, 11, 8),
        date(2018, 12, 25),
        date(2018, 2, 13),
        date(2018, 2, 13),
        date(2018, 3, 2),
        date(2018, 3, 2),
        date(2018, 3, 29),
        date(2018, 3, 29),
        date(2018, 3, 30),
        date(2018, 3, 30),
        date(2018, 4, 10),
        date(2018, 4, 6),
        date(2018, 4, 9),
        date(2018, 5, 1),
        date(2018, 8, 15),
        date(2018, 8, 22),
        date(2018, 9, 13),
        date(2018, 9, 20),
        date(2019, 10, 2),
        date(2019, 10, 21),
        date(2019, 10, 28),
        date(2019, 10, 8),
        date(2019, 11, 12),
        date(2019, 12, 25),
        date(2019, 3, 21),
        date(2019, 3, 4),
        date(2019, 4, 17),
        date(2019, 4, 19),
        date(2019, 4, 29),
        date(2019, 5, 1),
        date(2019, 6, 5),
        date(2019, 8, 12),
        date(2019, 8, 15),
        date(2019, 9, 10),
        date(2019, 9, 2),
        date(2020, 10, 2),
        date(2020, 11, 16),
        date(2020, 11, 30),
        date(2020, 12, 25),
        date(2020, 2, 21),
        date(2020, 3, 10),
        date(2020, 4, 10),
        date(2020, 4, 14),
        date(2020, 4, 2),
        date(2020, 4, 6),
        date(2020, 5, 1),
        date(2020, 5, 25),
        date(2021, 1, 26),
        date(2021, 10, 15),
        date(2021, 10, 15),
        date(2021, 11, 19),
        date(2021, 11, 19),
        date(2021, 11, 5),
        date(2021, 11, 5),
        date(2021, 3, 11),
        date(2021, 3, 29),
        date(2021, 4, 14),
        date(2021, 4, 2),
        date(2021, 4, 21),
        date(2021, 5, 13),
        date(2021, 7, 21),
        date(2021, 7, 21),
        date(2021, 8, 10),
        date(2021, 8, 19),
        date(2021, 8, 19),
        date(2021, 9, 10),
        date(2021, 9, 10),
        date(2022, 1, 26),
        date(2022, 10, 25),
        date(2022, 10, 26),
        date(2022, 10, 5),
        date(2022, 11, 8),
        date(2022, 3, 1),
        date(2022, 3, 18),
        date(2022, 4, 14),
        date(2022, 4, 15),
        date(2022, 4, 28),
        date(2022, 5, 2),
        date(2022, 5, 27),
        date(2022, 5, 27),
        date(2022, 5, 3),
        date(2022, 6, 1),
        date(2022, 8, 15),
        date(2022, 8, 31),
        date(2022, 8, 9),
        date(2023, 1, 26),
        date(2023, 10, 2),
        date(2023, 10, 24),
        date(2023, 11, 14),
        date(2023, 11, 27),
        date(2023, 12, 25),
        date(2023, 3, 30),
        date(2023, 3, 7),
        date(2023, 4, 14),
        date(2023, 4, 4),
        date(2023, 4, 7),
        date(2023, 5, 1),
        date(2023, 6, 29),
        date(2023, 8, 15),
        date(2023, 9, 19),
        date(2024, 1, 22),
        date(2024, 1, 26),
        date(2024, 3, 8),
        date(2024, 3, 25),
        date(2024, 3, 29),
        date(2024, 4, 11),
        date(2024, 4, 17),
        date(2024, 5, 1),
        date(2024, 6, 17),
        date(2024, 7, 17),
        date(2024, 8, 15),
        date(2024, 10, 2),
        date(2024, 11, 1),
        date(2024, 11, 15),
        date(2024, 12, 25),
    ]
